tools.tool_query

tool_query(executor, *, multi_table=False)

Create a tool that performs a SQL query on the data.

Parameters

Name Type Description Default
executor QueryExecutor The query executor to use for running queries. required
multi_table bool Whether multiple tables are registered. When True, multi-table query guidance is included in the tool description. False

Returns

Name Type Description
Tool A tool that can be registered with chatlas.