tools.tool_reset_dashboard

tool_reset_dashboard(reset_fn, table_names=None)

Create a tool that resets the dashboard to show all data.

Parameters

Name Type Description Default
reset_fn ResetDashboardCallback Callback function to call with table name when reset is requested. required
table_names list[str] | None Optional list of valid table names for validation. None

Returns

Name Type Description
Tool A tool that can be registered with chatlas.