tools.tool_update_dashboard

tool_update_dashboard(executor, table_names, update_fn, *, multi_table=False)

Create a tool that modifies the data presented in the dashboard.

Parameters

Name Type Description Default
executor QueryExecutor The query executor to validate queries against. required
table_names list[str] List of valid table names for validation. required
update_fn Callable[[UpdateDashboardData], None] Callback function to call with UpdateDashboardData when update succeeds. required
multi_table bool Whether multiple tables are registered. False

Returns

Name Type Description
Tool A tool that can be registered with chatlas.