Commons.add_turn()
Add a turn, restarting the citation request if a person spoke.
Usage
Commons.add_turn(turn)A user turn of nothing but tool results is the same question still running, and an assistant turn is nobody asking anything.
Add a turn, restarting the citation request if a person spoke.
Usage
A user turn of nothing but tool results is the same question still running, and an assistant turn is nobody asking anything.