tools.tool_visualize
tool_visualize(executor, update_fn, *, multi_table=False)Create a tool that executes a ggsql query and renders the visualization.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| executor | QueryExecutor |
The query executor to query against | required |
| update_fn | Callable[[VisualizeData], None] |
Callback function to call with VisualizeData when visualization succeeds | required |
| multi_table | bool | Whether multiple tables are registered. | False |
Returns
| Name | Type | Description |
|---|---|---|
Tool |
A tool that can be registered with chatlas |