tools.tool_visualize
tool_visualize(data_source, update_fn)Create a tool that executes a ggsql query and renders the visualization.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| data_source | DataSource | The data source to query against | required |
| update_fn | Callable[[VisualizeData], None] |
Callback function to call with VisualizeData when visualization succeeds | required |
Returns
| Name | Type | Description |
|---|---|---|
Tool |
A tool that can be registered with chatlas |